### Section 4.1 - Series Creation

#### 4.1.1 - Series Establishment Requirements

1. **Authorization Requirements**: New series may be established only upon:

   * Submission of a formal series establishment proposal to the Company Committee
   
   * Approval by a majority vote of the Company Committee
   
   * Filing of required notices with the Texas Secretary of State
   
   * Execution of a series operating agreement
   
   * Compliance with all requirements set forth in this Section 4.1
   
   * Completion of a pre-establishment compliance review by the Compliance and Ethics Committee
   
   * Verification that the proposed series will not create conflicts with existing series
   
   * Confirmation of available resources to support the new series
   
   * Certification that the series will comply with all mandatory service provider requirements
   
   * Completion of required regulatory filings in all applicable jurisdictions

2. **Series Establishment Proposal**: Any proposal for establishing a new series must include:

   * Proposed business purpose and scope of operations
   
   * Three-year business plan with financial projections
   
   * Management structure and key personnel
   
   * Initial members and proposed membership interests
   
   * Draft series operating agreement
   
   * Risk assessment and mitigation strategy
   
   * Compliance plan for all mandatory requirements
   
   * Integration strategy with existing TSYS Group entities
   
   * Detailed financial model with capitalization requirements
   
   * Market analysis and competitive landscape assessment
   
   * Exit strategy or long-term sustainability plan
   
   * Technology requirements and integration plan
   
   * Regulatory analysis and compliance strategy
   
   * Intellectual property strategy
   
   * Staffing plan and organizational structure
   
   * Service provider integration plan
   
   * Capital raising strategy and timeline
   
   * Performance metrics and success criteria
   
   * Governance structure and decision-making framework
   
   * Potential risks and mitigation strategies
   
   * Environmental, Social, and Governance (ESG) considerations

3. **Series Documentation Requirements**: Each series must maintain:

   * A series operating agreement executed by all initial members and the Company Committee
   
   * A certificate of series filing with the Texas Secretary of State
   
   * A unique federal Employer Identification Number (EIN)
   
   * Separate books and records as required by Section 3.2
   
   * All registrations, licenses, and permits required for its business operations
   
   * Compliance documentation for securities law requirements
   
   * Insurance coverage appropriate to the series' activities
   
   * Service level agreements with mandatory service providers
   
   * Business continuity and disaster recovery plans
   
   * Cybersecurity and data protection policies
   
   * Conflict of interest policies and disclosures
   
   * Code of ethics and conduct
   
   * Risk management framework and controls
   
   * Personnel policies and procedures
   
   * Tax compliance documentation
   
   * Banking and financial account documentation

4. **Approval Process Timeline**:

   * The Company Committee shall review series establishment proposals within 45 days of submission
   
   * Requestors shall receive written notification of approval or denial within 15 days of the Committee's decision
   
   * If denied, the notification shall include the specific reasons for denial and any remedial actions that could be taken
   
   * Approved series must complete all required documentation within 90 days of approval
   
   * The series must commence operations within 180 days of approval unless an extension is granted
   
   * The Company Committee may approve proposals conditionally, subject to specific modifications or additional requirements
   
   * Appeals of denied proposals may be submitted to the Board within 30 days of denial
   
   * The Board shall review appeals within 60 days and its decision shall be final

5. **Post-Approval Requirements**:

   * New series shall undergo a 90-day implementation review
   
   * Quarterly performance reviews shall be conducted for the first year of operations
   
   * Annual compliance certification shall be required
   
   * Implementation of all required policies and procedures within 60 days of establishment
   
   * Completion of all required training for series personnel
   
   * Integration with service providers within timeframes specified in the approval
   
   * Submission of quarterly progress reports against business plan for the first year
   
   * Participation in Company orientation programs

#### 4.1.2 - Series Operating Agreement Requirements

1. **Required Elements**: Each series operating agreement shall include provisions addressing:

   * Business purpose and operational scope
   
   * Membership structure and classes
   
   * Profit interest allocation and distribution
   
   * Governance structure and decision-making processes
   
   * Management rights and responsibilities
   
   * Transfer restrictions
   
   * Dispute resolution procedures
   
   * Term and dissolution provisions
   
   * Compliance with all mandatory Company requirements
   
   * Capital call provisions and procedures
   
   * Valuation methodologies
   
   * Information rights
   
   * Non-competition and confidentiality provisions
   
   * Required adherence to Company policies
   
   * Indemnification provisions
   
   * Insurance requirements
   
   * Intellectual property rights and protections
   
   * Amendment procedures
   
   * Tax matters and allocations
   
   * Regulatory compliance commitments
   
   * Record-keeping requirements
   
   * Reporting obligations to the Company
   
   * Service provider relationships
   
   * Member withdrawal and removal provisions
   
   * Capital account treatment (consistent with profit interest structure)
   
   * Succession planning requirements
   
   * Risk management framework
   
   * Ethics and conduct standards

2. **Series Operating Agreement Flexibility**: Within the parameters established by this Agreement, series shall have broad latitude to establish:

   * Custom governance structures appropriate to their business needs
   
   * Specialized profit interest allocation methodologies
   
   * Unique membership qualifications and admission procedures
   
   * Industry-specific operational procedures and standards
   
   * Tailored distribution structures and timing
   
   * Other provisions specific to their business purposes or investment objectives
   
   * Specialized committee structures
   
   * Industry-appropriate risk management frameworks
   
   * Customized performance metrics and incentives
   
   * Specific succession planning mechanisms
   
   * Tailored dispute resolution procedures
   
   * Industry-specific compliance programs
   
   * Specialized intellectual property protection strategies
   
   * Customized member qualification requirements
   
   * Tailored reporting frameworks for members

3. **Series Operating Agreement Limitations**: No series operating agreement may:

   * Override or conflict with any provision of this Agreement
   
   * Alter the required service provider relationships established in Article 3
   
   * Modify the electronic records requirements established in Section 3.2
   
   * Change the capital raising requirements established in Section 3.3
   
   * Eliminate or reduce Company-level compliance measures
   
   * Violate any securities laws or regulations
   
   * Attempt to limit the isolation of series as provided in Section 4.2
   
   * Eliminate fiduciary duties to the extent non-waivable under Texas law
   
   * Create joint liability among series
   
   * Establish capital accounts or capital interests
   
   * Create membership classes other than those specified in Article 5
   
   * Circumvent the governance structure established in Article 7
   
   * Modify the dispute resolution procedures in Schedule H
   
   * Override tax classification provisions
   
   * Restrict required information access by the Company Committee
   
   * Establish provisions that would jeopardize securities law exemptions
   
   * Create membership interests that are inconsistent with the profit interest structure
   
   * Attempt to opt out of mandatory governance requirements
   
   * Establish indemnification provisions broader than permitted by law
   
   * Create any cross-series guarantees or credit support

4. **Conflict Resolution**: Any provision in a series operating agreement that conflicts with this Agreement shall be void and unenforceable. In case of any ambiguity or dispute regarding potential conflicts, the Company Committee shall have final authority to interpret and resolve such conflicts.

5. **Standard Template Requirements**: Each series operating agreement shall:

   * Be based on standard templates approved by the Company Committee
   
   * Maintain consistent formatting and section numbering across all series
   
   * Include required legal disclosures and notices
   
   * Be reviewed by legal counsel prior to adoption
   
   * Be properly executed using the electronic signature system
   
   * Include all required schedules and exhibits
   
   * Contain appropriate securities law disclosures
   
   * Include mandatory risk factor disclosures
   
   * Incorporate required tax provisions
   
   * Implement standard governance provisions
   
   * Contain mandatory service provider provisions
   
   * Include standard compliance language
   
   * Incorporate required dispute resolution procedures
   
   * Maintain consistent definitions aligned with this Agreement
   
   * Include appropriate cross-references to this Agreement

6. **Legal Review and Compliance**:

   * Each series operating agreement must undergo legal review by:
   
     * Company counsel for compliance with this Agreement
     
     * Securities counsel for compliance with applicable securities laws
     
     * Tax counsel for proper tax treatment
     
     * Regulatory counsel if the series operates in regulated industries
   
   * Written certification of legal review must be maintained in the electronic records system
   
   * Any non-standard provisions must be specifically identified and approved by the Company Committee
   
   * Regular compliance reviews must be conducted to ensure continued alignment with changing laws and regulations
   
   * Annual certification of compliance with this Agreement must be provided

#### 4.1.3 - Series Amendment Process

1. **Series Operating Agreement Amendments**: Any series operating agreement may be amended according to its own terms, provided that:

   * The amendment does not create a conflict with this Agreement
   
   * Notice of the amendment is provided to the Company Committee within 10 business days
   
   * The amendment is properly documented in the electronic records system
   
   * The amendment complies with all applicable laws and regulations
   
   * Material amendments receive legal review prior to adoption
   
   * The amendment is formally approved according to the procedures in the series operating agreement
   
   * All series members receive notice of the amendment
   
   * The amendment is properly executed using the electronic signature system
   
   * The amendment is implemented consistently with all Company policies
   
   * The amendment does not materially alter the rights of existing members without their consent

2. **Series Purpose Modifications**: Any material change to a series' business purpose or operational scope requires:

   * Prior written approval of the Company Committee
   
   * Amended filings with the Texas Secretary of State if required
   
   * Compliance with any applicable regulatory requirements
   
   * Updated business plan and risk assessment
   
   * Notification to all series members
   
   * Legal review for continued compliance with securities laws
   
   * Assessment of tax implications
   
   * Evaluation of impact on existing contracts and relationships
   
   * Analysis of potential conflicts with other series
   
   * Re-evaluation of insurance and risk management needs
   
   * Potential re-verification of investor qualifications
   
   * Review of capital raising strategy alignment
   
   * Assessment of service provider capability alignment
   
   * Evaluation of governance structure appropriateness
   
   * Review of required licenses and permits

3. **Amendment Approval Process**:

   * Proposed amendments must be submitted in writing
   
   * Required approvals must be documented in the electronic records system
   
   * Company Committee review shall be completed within 30 days
   
   * Rejected amendments may be revised and resubmitted
   
   * Approved amendments become effective upon execution by all required parties
   
   * Material amendments must be distributed to all members
   
   * Securities law implications must be evaluated for all amendments
   
   * Tax implications must be analyzed by qualified tax advisors
   
   * Regulatory filing requirements must be assessed
   
   * Implementation plan must be developed for significant amendments
   
   * Documentation of amendment consideration process must be maintained

4. **Emergency Amendments**: In case of regulatory changes or other urgent circumstances:

   * The Company Committee may implement temporary amendments
   
   * Temporary amendments must be ratified within 90 days
   
   * Series members must be promptly notified of emergency amendments
   
   * Documentation must include justification for the emergency action
   
   * The temporary nature of the amendment must be clearly indicated
   
   * A plan for permanent resolution must be developed
   
   * Emergency amendments must be specifically identified in the electronic records system
   
   * Regular amendments must replace emergency amendments within the specified timeframe
   
   * Emergency amendment authority must be narrowly construed
   
   * The Board must be notified of all emergency amendments within 5 business days

5. **Amendment Documentation Requirements**:

   * All amendments must be maintained in the electronic records system
   
   * Version control must be maintained for all operating agreements
   
   * Comparison documents showing changes must be created
   
   * Executive summaries of material changes must be provided to members
   
   * Approval documentation must be maintained
   
   * Legal review documentation must be preserved
   
   * Implementation records must be maintained
   
   * Member notifications must be documented
   
   * Regulatory filings must be stored in the electronic records system
   
   * Tax analysis documentation must be preserved
   
   * Compliance verification must be documented
   
   * Record of member votes or consents must be maintained
   
   * Certification of compliance with amendment procedures must be created